============
Installation
============


Through pip
-----------


.. code-block:: bash

    $ pip install gems


Via GitHub
----------


.. code-block:: bash

    $ git clone http://github.com/bprinty/faux.git
    $ cd faux
    $ python setup.py install


Questions/Feedback
------------------

File an issue in the `GitHub issue tracker <https://github.com/bprinty/faux/issues>`_.
